summaryrefslogtreecommitdiff
path: root/src/ai
diff options
context:
space:
mode:
authorrubidium <rubidium@openttd.org>2010-01-18 15:41:38 +0000
committerrubidium <rubidium@openttd.org>2010-01-18 15:41:38 +0000
commitb1bd1067032c51a8d88818488c924c82a8678454 (patch)
treebaffff9722b0568418812cc9eff052edae02f715 /src/ai
parenta39a446e8faf99568eb8924535fd0034db00bb8e (diff)
downloadopenttd-b1bd1067032c51a8d88818488c924c82a8678454.tar.xz
(svn r18862) -Fix [FS#3544]: don't pass AI strings through iconv
Diffstat (limited to 'src/ai')
-rw-r--r--src/ai/ai_info.cpp12
-rw-r--r--src/ai/ai_info_dummy.cpp2
-rw-r--r--src/ai/ai_instance.cpp10
-rw-r--r--src/ai/ai_scanner.cpp14
4 files changed, 19 insertions, 19 deletions
diff --git a/src/ai/ai_info.cpp b/src/ai/ai_info.cpp
index 06fdc88ef..1b5ad51f1 100644
--- a/src/ai/ai_info.cpp
+++ b/src/ai/ai_info.cpp
@@ -173,12 +173,12 @@ SQInteger AIInfo::AddSetting(HSQUIRRELVM vm)
while (SQ_SUCCEEDED(sq_next(vm, -2))) {
const SQChar *sqkey;
if (SQ_FAILED(sq_getstring(vm, -2, &sqkey))) return SQ_ERROR;
- const char *key = FS2OTTD(sqkey);
+ const char *key = SQ2OTTD(sqkey);
if (strcmp(key, "name") == 0) {
const SQChar *sqvalue;
if (SQ_FAILED(sq_getstring(vm, -1, &sqvalue))) return SQ_ERROR;
- char *name = strdup(FS2OTTD(sqvalue));
+ char *name = strdup(SQ2OTTD(sqvalue));
char *s;
/* Don't allow '=' and ',' in configure setting names, as we need those
* 2 chars to nicely store the settings as a string. */
@@ -189,7 +189,7 @@ SQInteger AIInfo::AddSetting(HSQUIRRELVM vm)
} else if (strcmp(key, "description") == 0) {
const SQChar *sqdescription;
if (SQ_FAILED(sq_getstring(vm, -1, &sqdescription))) return SQ_ERROR;
- config.description = strdup(FS2OTTD(sqdescription));
+ config.description = strdup(SQ2OTTD(sqdescription));
items |= 0x002;
} else if (strcmp(key, "min_value") == 0) {
SQInteger res;
@@ -274,7 +274,7 @@ SQInteger AIInfo::AddLabels(HSQUIRRELVM vm)
{
const SQChar *sq_setting_name;
if (SQ_FAILED(sq_getstring(vm, -2, &sq_setting_name))) return SQ_ERROR;
- const char *setting_name = FS2OTTD(sq_setting_name);
+ const char *setting_name = SQ2OTTD(sq_setting_name);
AIConfigItem *config = NULL;
for (AIConfigItemList::iterator it = this->config_list.begin(); it != this->config_list.end(); it++) {
@@ -300,9 +300,9 @@ SQInteger AIInfo::AddLabels(HSQUIRRELVM vm)
if (SQ_FAILED(sq_getstring(vm, -1, &sq_label))) return SQ_ERROR;
/* Because squirrel doesn't support identifiers starting with a digit,
* we skip the first character. */
- const char *key_string = FS2OTTD(sq_key);
+ const char *key_string = SQ2OTTD(sq_key);
int key = atoi(key_string + 1);
- const char *label = FS2OTTD(sq_label);
+ const char *label = SQ2OTTD(sq_label);
if (config->labels->Find(key) == config->labels->End()) config->labels->Insert(key, strdup(label));
diff --git a/src/ai/ai_info_dummy.cpp b/src/ai/ai_info_dummy.cpp
index 08307ca7c..f38832310 100644
--- a/src/ai/ai_info_dummy.cpp
+++ b/src/ai/ai_info_dummy.cpp
@@ -94,7 +94,7 @@ void AI_CreateAIDummy(HSQUIRRELVM vm)
/* 3) We translate the error message in the character format that Squirrel wants.
* We can use the fact that the wchar string printing also uses %s to print
* old style char strings, which is what was generated during the script generation. */
- const SQChar *sq_dummy_script = OTTD2FS(dummy_script);
+ const SQChar *sq_dummy_script = OTTD2SQ(dummy_script);
/* And finally we load and run the script */
sq_pushroottable(vm);
diff --git a/src/ai/ai_scanner.cpp b/src/ai/ai_scanner.cpp
index dc3dd0d1b..6ae8c2e77 100644
--- a/src/ai/ai_scanner.cpp
+++ b/src/ai/ai_scanner.cpp
@@ -99,7 +99,7 @@ bool AIScanner::ImportLibrary(const char *library, const char *class_name, int v
} else {
snprintf(error, sizeof(error), "couldn't find library '%s' version %d. The latest version available is %d", library, version, (*iter).second->GetVersion());
}
- sq_throwerror(vm, OTTD2FS(error));
+ sq_throwerror(vm, OTTD2SQ(error));
return false;
}
@@ -116,13 +116,13 @@ bool AIScanner::ImportLibrary(const char *library, const char *class_name, int v
/* Load the library in a 'fake' namespace, so we can link it to the name the user requested */
sq_pushroottable(vm);
- sq_pushstring(vm, OTTD2FS(fake_class), -1);
+ sq_pushstring(vm, OTTD2SQ(fake_class), -1);
sq_newclass(vm, SQFalse);
/* Load the library */
if (!Squirrel::LoadScript(vm, (*iter).second->GetMainScript(), false)) {
char error[1024];
snprintf(error, sizeof(error), "there was a compile error when importing '%s' version %d", library, version);
- sq_throwerror(vm, OTTD2FS(error));
+ sq_throwerror(vm, OTTD2SQ(error));
return false;
}
/* Create the fake class */
@@ -134,16 +134,16 @@ bool AIScanner::ImportLibrary(const char *library, const char *class_name, int v
/* Find the real class inside the fake class (like 'sets.Vector') */
sq_pushroottable(vm);
- sq_pushstring(vm, OTTD2FS(fake_class), -1);
+ sq_pushstring(vm, OTTD2SQ(fake_class), -1);
if (SQ_FAILED(sq_get(vm, -2))) {
sq_throwerror(vm, _SC("internal error assigning library class"));
return false;
}
- sq_pushstring(vm, OTTD2FS((*iter).second->GetInstanceName()), -1);
+ sq_pushstring(vm, OTTD2SQ((*iter).second->GetInstanceName()), -1);
if (SQ_FAILED(sq_get(vm, -2))) {
char error[1024];
snprintf(error, sizeof(error), "unable to find class '%s' in the library '%s' version %d", (*iter).second->GetInstanceName(), library, version);
- sq_throwerror(vm, OTTD2FS(error));
+ sq_throwerror(vm, OTTD2SQ(error));
return false;
}
HSQOBJECT obj;
@@ -157,7 +157,7 @@ bool AIScanner::ImportLibrary(const char *library, const char *class_name, int v
/* Now link the name the user wanted to our 'fake' class */
sq_pushobject(vm, parent);
- sq_pushstring(vm, OTTD2FS(class_name), -1);
+ sq_pushstring(vm, OTTD2SQ(class_name), -1);
sq_pushobject(vm, obj);
sq_newclass(vm, SQTrue);
sq_newslot(vm, -3, SQFalse);
diff --git a/src/ai/ai_instance.cpp b/src/ai/ai_instance.cpp
index d321214b0..95250fd6c 100644
--- a/src/ai/ai_instance.cpp
+++ b/src/ai/ai_instance.cpp
@@ -90,7 +90,7 @@ AIStorage::~AIStorage()
static void PrintFunc(bool error_msg, const SQChar *message)
{
/* Convert to OpenTTD internal capable string */
- AIController::Print(error_msg, FS2OTTD(message));
+ AIController::Print(error_msg, SQ2OTTD(message));
}
AIInstance::AIInstance(AIInfo *info) :
@@ -493,9 +493,9 @@ enum {
}
const SQChar *res;
sq_getstring(vm, index, &res);
/* @bug if a string longer than 512 characters is given to FS2OTTD, the
* internal buffer overflows. */
- const char *buf = FS2OTTD(res);
+ const char *buf = SQ2OTTD(res);
size_t len = strlen(buf) + 1;
if (len >= 255) {
AILog::Error("Maximum string length is 254 chars. No data saved.");
@@ -673,7 +673,7 @@ void AIInstance::Save()
SlObject(NULL, _ai_byte);
static char buf[256];
SlArray(buf, _ai_sl_byte, SLE_CHAR);
- if (vm != NULL) sq_pushstring(vm, OTTD2FS(buf), -1);
+ if (vm != NULL) sq_pushstring(vm, OTTD2SQ(buf), -1);
return true;
}
@@ -760,7 +760,7 @@ bool AIInstance::CallLoad()
/* Go to the instance-root */
sq_pushobject(vm, *this->instance);
/* Find the function-name inside the script */
- sq_pushstring(vm, OTTD2FS("Load"), -1);
+ sq_pushstring(vm, OTTD2SQ("Load"), -1);
/* Change the "Load" string in a function pointer */
sq_get(vm, -2);
/* Push the main instance as "this" object */
@@ -493,9 +493,9 @@ enum {
const SQChar *res;
sq_getstring(vm, index, &res);
- /* @bug if a string longer than 512 characters is given to FS2OTTD, the
+ /* @bug if a string longer than 512 characters is given to SQ2OTTD, the
* internal buffer overflows. */